@@ -126,7 +126,7 @@ class Witter():
         self.retweetid = ""
         self.retweettext = ""
         self.selectedUser = ""
-
+        self.theme = "default"
 
         #
         #go read config file
@@ -156,8 +156,8 @@ class Witter():
         #pass the witter ui a reference to this object for callbacks
         self.ui = ui.WitterUI(self)
         self.ui.setActiveListStore(self.activeAccount.getTimeline())
-
-
+        self.ui.theme = self.theme
+        self.ui.select_ui_theme(self.theme)
         self.gettingTweets = False
         if (self.activeAccount.getUsername() != "Username"):
             self.start_refresh_threads()
@@ -360,6 +360,7 @@ class Witter():
                 print bottomCol
                 self.bg_bottom_color = gtk.gdk.color_parse(bottomCol)
                 self.font_size = int(config.get("UI", "font_size"))
+                self.theme = config.get("UI", "theme")
             except ConfigParser.NoSectionError:
                 print "no text colour setting"
             except ConfigParser.NoOptionError:
@@ -470,6 +471,7 @@ class Witter():
             f.write("bg_top = " + self.ui.bg_top_color.to_string() + "\n")
             f.write("bg_bottom = " + self.ui.bg_bottom_color.to_string() + "\n")
             f.write("font_size = " + str(self.font_size) + "\n")
+            f.write("theme = " + self.ui.theme + "\n")
             f.write("[refresh_interval]\n")
             f.write("timeline = " + str(self.timelineRefreshInterval) + "\n")
             f.write("mentions = " + str(self.mentionsRefreshInterval) + "\n")
@@ -841,6 +843,10 @@ class Witter():
                             print "bitly gave error response"
                         except KeyError:
                             print "bitly gave key error response"
+                        except BadStatusLine, e2:
+                            print e2
+                            note = osso.SystemNote(self.osso_c)
+                            note.system_note_dialog("Bad status response")
         return data
 
 
